@@ -5,6 +5,7 @@ decompsigma.I <- function(full, sigma.ill = .FC.CT$CONTROL$sigma.ill){
   DS <- sqrt(full)
   DS.check <- TRUE
   if(min(DS) / max(DS) < sigma.ill){
+    .MixfMRIEnv$cat("Checks via min(DS)/max(DS) may have errors.\n", quiet = TRUE)
     DS.check <- FALSE
   }
 
@@ -12,8 +13,9 @@ decompsigma.I <- function(full, sigma.ill = .FC.CT$CONTROL$sigma.ill){
 } # End of decompsigma.I().
 
 decompsigma.V <- function(full, sigma.ill = .FC.CT$CONTROL$sigma.ill){
-  DS <- try(chol(full))
-  if(class(DS) == "try-error"){
+  DS <- try(chol(full), silent = TRUE)
+  if(inherits(DS, "try-error")){
+    .MixfMRIEnv$cat("Checks via chol() may have errors.\n", quiet = TRUE)
     DS.check <- FALSE
   } else{
     ds <- diag(DS)
